==> accountbook-3.0b1.tar.gz: accountbook-3.0b1/public/admin.rb <==
#!/home/netsphere/bin/ruby
# -*- coding:utf-8 -*-

# Q's Account Book
# Copyright (c) 2002 HORIKAWA Hisashi. All rights reserved.
#   mailto:vzw00011@nifty.ne.jp
#   http://www.nslabs.jp/

# ユーザー名・パスワード・メールアドレス等変更

require "pcview.rb"

$SAFE = 1

USER_EXPIRATION = 300   # 単位：日

def get_last_time(userid)
  if FileTest.exist?(FilePath.journal(userid))
    last_time = File.mtime(FilePath.journal(userid))
  elsif FileTest.exist?(FilePath.profile(userid))
    last_time = File.mtime(FilePath.profile(userid))
  else
    last_time = Time.at(0)
  end
end

class DelAF < Wafu::ActionForm
  attr_reader :sel
  def setup()
    @sel = @app.cgi.params['sel']
  end

  def validate()
    err = []
    @sel.each {|userid|
      last_time = get_last_time(userid)
      interval_day = Integer(Time.now - last_time) / (60 * 60 * 24)
      if interval_day <= USER_EXPIRATION
        err << "ユーザー#{userid} は、経過日数が #{USER_EXPIRATION} 日を超えていません。"
      end
    }
    return set_error(err)
  end
end

class DeleteUser < Wafu::Action
  def delete_user(users)
    users_deleted = PasswdStore.new(FilePath.passwd + '.deleted')
    users.each {|name|
      ent = @app.db.delete_user(name)
      users_deleted.add_user(ent)
      data_dir = PRIVATE_DIR + '/' + name
      if FileTest.exist?(data_dir)
        File.rename(data_dir, data_dir + ".deleted")
      end
    }
  end

  def execute(af)
    print "Content-Type:text/html\n\n"
    print af.sel
    delete_user(af.sel)
  end
end

class MenuForm < Wafu::Action
  def execute(af)
    entries = []
    @app.db.get_users().each {|u|
      entries << @app.db.get_passwd(u)
    }

    model = {:userlist => []}
    if af && af.error?
      model[:error] = []
      af.errors.each {|s|
        model[:error] << {:message => s}
      }
    end

    entries.each {|ent|
      last_time = get_last_time(ent.name)
      interval_day = Integer(Time.now - last_time) / (60 * 60 * 24)
      line = {
        :userid => ent.name,
        :check => interval_day <= USER_EXPIRATION ? nil :
               {:userid => ent.name,
                :checked => (af && !af.sel.include?(ent.name) ? nil : "checked")},
        :last_time => sprintf("%04d.%02d.%02d",
                              last_time.year, last_time.mon, last_time.day),
        :interval => interval_day > USER_EXPIRATION ? "color:red" : nil,
        :days => "#{interval_day}日",
      }
      model[:userlist] << line
    }

    @app.page_out("admin-menu.html", model)
  end
end

class AdminMenu < PCView
  def main()
    actions = {
      "*" => [nil, MenuForm, nil],
      "del" => [DelAF, DeleteUser, MenuForm]
    }
    dispatch(actions)
  end
end

if __FILE__ == $0
  AdminMenu.new({"session_type" => "none"}).run()
end

==> accountbook-3.0.0.tar.gz: accountbook-3.0.0/public/admin.rb <==
#!/home/netsphere/bin/ruby
# -*- coding:utf-8 -*-

# Q's Account Book
# Copyright (c) 2002 HORIKAWA Hisashi. All rights reserved.
#   mailto:vzw00011@nifty.ne.jp
#   http://www.nslabs.jp/

# 管理者用: 長期間利用していないユーザデータを削除する

require "pcview.rb"
require 'time'
require APP_ROOT + '/models/journal_entry'
require APP_ROOT + '/models/email_log'
require APP_ROOT + '/models/payment'
require APP_ROOT + '/models/invoice'
require APP_ROOT + '/models/partner'
require APP_ROOT + '/models/budget'
require APP_ROOT + '/models/account_title'
require APP_ROOT + '/models/user_setting'


USER_EXPIRATION = 300   # 単位：日

def get_last_time(user)
  ary = []
  je = JournalEntry.find(:first, 
                         :select => 'MAX(created_at) as ct',
                         :conditions => ['user_id = ?', user.id])
  ary << Time.parse(je.ct) if je && je.ct 
  ary << user.updated_at if user.updated_at
  ary << user.created_at 

  return ary.max
end

class DelAF < Wafu::ActionForm
  attr_reader :sel
  def setup()
    @sel = @app.cgi.params['sel']
  end

  def validate()
    err = []
    @sel.each {|userid|
      last_time = get_last_time(User.find_by_login(userid))
      interval_day = Integer(Time.now - last_time) / (60 * 60 * 24)
      if interval_day <= USER_EXPIRATION
        err << "ユーザー#{userid} は、経過日数が #{USER_EXPIRATION} 日を超えていません。"
      end
    }
    return set_error(err)
  end
end

class DeleteUser < Wafu::Action
  def execute(af)
    print "Content-Type:text/html\n\n"
    print af.sel # DEBUG
    User.delete_user_data(af.sel)
  end
end

class MenuForm < Wafu::Action
  def execute(af)
    entries = User.find :all

    model = {:userlist => []}
    if af && af.error?
      model[:error] = []
      af.errors.each {|s|
        model[:error] << {:message => s}
      }
    end

    entries.each {|ent|
      last_time = get_last_time(ent)
      interval_day = Integer(Time.now - last_time) / (60 * 60 * 24)
      line = {
        :login => ent.login,
        :name => ent.name, # 氏名
        :check => interval_day <= USER_EXPIRATION ? nil :
               {:userid => ent.login,
                :checked => (af && !af.sel.include?(ent.name) ? nil : "checked")},
        :last_time => sprintf("%04d.%02d.%02d",
                              last_time.year, last_time.mon, last_time.day),
        :interval => interval_day > USER_EXPIRATION ? "color:red" : nil,
        :days => "#{interval_day}日",
      }
      model[:userlist] << line
    }

    @app.page_out("admin-menu.html", model)
  end
end

class AdminMenu < PCView
  def main()
    actions = {
      "*" => [nil, MenuForm, nil],
      "del" => [DelAF, DeleteUser, MenuForm]
    }
    dispatch(actions)
  end
end

if __FILE__ == $0
  AdminMenu.new({"session_type" => "none"}).run()
end
